bvg-grabber
===========

Showing BVG Departures In Your Office
+++++++++++++++++++++++++++++++++++++

.. image:: https://secure.travis-ci.org/Markush2010/bvg-grabber.png?branch=master
    :alt: Build Status
    :target: http://travis-ci.org/Markush2010/bvg-grabber

Blog post:
  http://markusholtermann.eu/article/showing-bvg-departures-in-your-office/
  
Slides:
  http://download.markusholtermann.eu/BVG-Grabber-LightningTalk.pdf

Pictures:
  .. image:: http://media.markusholtermann.eu/img/BVG-Grabber-LightningTalk-installation1tb.jpg
      :alt: Installation 1
    
  .. image:: http://media.markusholtermann.eu/img/BVG-Grabber-LightningTalk-installation2tb.jpg
      :alt: Installation 2
